/* winutils.js

Window and layer info, move and size utilities
Written by Pintr Gbor
Feuerwehrgasse 1/2/9
Purbach am Neusiedlersee
A-7083, Austria 
Tel: +43 681 20821067, +36 20 4331532
Email: pinter.gabor@gmx.at
Web: http://www.pic18.eu

Revisions:
  V0.01 2001-10-17  Experimental
  V0.02 2001-12-19  IE6
  V1.0  2010-11-26  IE7, IE8
  V1.1  2014-03-14  Compatibility with really old browsers has been removed


This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 3
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

http://www.gnu.org/copyleft/gpl.html

For commercial license, and for other professional
JavaScript and Java components please contact the author.



Example: http://www.pic18.eu/en/www/winutils/

*/






// Find object by name or id
function findobj(id) {
	var i, x, d;
	d= arguments.length==2 ? arguments[1] : document;
	x= d[id];
	if (!x && d.all) x= d.all[id];
	for (i=0; !x && i<d.forms.length; i++) x= document.forms[i][id];
	if (!x && document.getElementById) x= document.getElementById(id);
	if (!x && document.getElementByName) x= document.getElementByName(id);
	for (i=0; !x && d.layers && i<d.layers.length; i++) x= findobj(id, d.layers[i].document);
	return(x);
}



// Window position and size
function getwinleft() {
	if (typeof(window.pageXOffset)=='number') {
		// Netscape compliant
		return window.pageXOffset;
	}
	if (document.body && (document.body.scrollLeft || document.body.scrollTop)) {
		// DOM compliant
		return document.body.scrollLeft;
	}
	if (document.documentElement && (document.documentElement.scrollLeft || document.documentElement.scrollTop)) {
		// IE6 standards compliant mode
		return document.documentElement.scrollLeft;
	}
	return 0;
}
function getwintop() {
	if (typeof(window.pageYOffset)=='number') {
		// Netscape compliant
		return window.pageYOffset;
	}
	if (document.body && (document.body.scrollLeft || document.body.scrollTop)) {
		// DOM compliant
		return document.body.scrollTop;
	}
	if (document.documentElement && (document.documentElement.scrollLeft || document.documentElement.scrollTop)) {
		// IE6 standards compliant mode
		return document.documentElement.scrollTop;
	}
	return 0;
}
function getwinwidth() {
	if (typeof(window.innerWidth)=='number') {
		// Non-IE
		return window.innerWidth;
	} 
	if (document.documentElement && (document.documentElement.clientWidth || document.documentElement.clientHeight)) {
		// IE 6+ in 'standards compliant mode'
		return document.documentElement.clientWidth;
	}
	if (document.body && (document.body.clientWidth || document.body.clientHeight)) {
		// IE 4 compatible
		return document.body.clientWidth;
	}
	return 0;
}
function getwinheight() {
	if (typeof(window.innerHeight)=='number') {
		// Non-IE
		return window.innerHeight;
	} 
	if (document.documentElement && (document.documentElement.clientWidth || document.documentElement.clientHeight)) {
		// IE 6+ in 'standards compliant mode'
		return document.documentElement.clientHeight;
	}
	if (document.body && (document.body.clientWidth || document.body.clientHeight)) {
		// IE 4 compatible
		return document.body.clientHeight;
	}
	return 0;
}



// Layer position and size
function getlywidth(ly) {
	if (ly.style) {
		return(ly.style.width);
	} else {
		return(-1);
	}
}
function getlyheight(ly) {
	if (ly.style) {
		return(ly.style.height);
	} else {
		return(-1);
	}
}
function getlyleft(ly) {
	if (ly.style) {
		return(ly.style.left);
	} else {
		return(ly.left);
	}
}
function getlytop(ly) {
	if (ly.style) {
		return(ly.style.top);
	} else {
		return(ly.top);
	}
}
function movely(ly, x, y) {
	if (!ly) return;
	if (ly.style) {
		ly.style.left= x;
		ly.style.top= y;
	} else {
		ly.left= x;
		ly.top= y;
	}
}
function resizely(ly, w, h) {
	if (!ly) return;
	if (ly.style) {
		ly.style.width= w;
		ly.style.height= h;
	}
}



// Layer z-index
function getlyzindex(ly) {
	if (ly.style) {
		return(ly.style.zIndex);
	} else {
		return(ly.zIndex);
	}
}
function setlyzindex(ly, z) {
	if (!ly) return;
	if (ly.style) {
		ly.style.zIndex= z;
	} else {
		ly.zIndex= z;
	}
}



// Layer show/hide
function showly(ly) {
	if (!ly) return;
	if (ly.style) {
		ly.style.visibility= "visible";
	} else {
		ly.visibility= "show";
	}
}
function hidely(ly) {
	if (!ly) return;
	if (ly.style) {
		ly.style.visibility= "hidden";
	} else {
		ly.visibility= "hide";
	}
}



// Mouse position
var mouse= { x:0, y:0 };



// Capture mouse position
window.addEventListener('mousemove', function(e) {
	mouse.x= e.pageX;
	mouse.y= e.pageY;
});
